==> flutter_catalogue_widgets-0.0.6.tar.gz: lib/custom-circularprogressindicator.dart <==
/*
Description:
A loader or circular progress indicator that can be used to indicate the completeness of something or act as a splash/wait page or element.
There are two types of Circular Progress Indicators: Definite and Indefinite
- Indefinite progress indicators are indefinitely moving that can be used to showcase progress without any particular values.
- Defintie progress indicators intake a value and show the progress accordingly. For example, 0.6 will show an indicator that is 60% complete.

Imports:
import 'custom-circularprogressindicator.dart';
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';

Usage:
The user can pass in parameters to the widget like value color, background color, custom animator etc.

    Please Note:
    value = 0 or value = null will create an indefinte Progress indicator

    CustomCircularProgressIndicatorParameters Parameters = new CustomCircularProgressIndicatorParameters(value: 0, backgroundColor: Colors.red, valueColor: Colors.white);
    CustomisedCircularProgressIndicator(Parameters)

Author:
Soumyadeep Mitra
*/

import 'package:flutter/material.dart';
import 'theme.dart';
import 'widget-classesUsed.dart';
import 'consts.dart' as cons;

Widget CustomisedCircularProgressIndicator(CustomCircularProgressIndicatorParameters Params) {
  // If no parameters are passed as a part of the widget call
  if(Params == null){
    return Container(
      padding: cons.edgeInsetValues,
      child: CircularProgressIndicator(
        value: cons.intialValue,
        backgroundColor: MediumGreyThemeData().backgroundColor,
        valueColor: new AlwaysStoppedAnimation<Color>(
            MediumGreyThemeData().accentColor),
      ),
    );
  }
  else {
    // If all or limited parameters are passed as part of the parameters
    return Container(
      padding: cons.edgeInsetValues,
      child: CircularProgressIndicator(
        value: (Params.value == 0 || Params.value == null)
            ? null
            : Params.value, // If value is null or 0, the bar is non-definite, else it will take the value
        backgroundColor: (Params.backgroundColor!=null)?Params.backgroundColor:MediumGreyThemeData().backgroundColor,
        valueColor: (Params.valueColor!=null)?new AlwaysStoppedAnimation<Color>(Params.valueColor):new AlwaysStoppedAnimation<Color>(
            MediumGreyThemeData().accentColor),
      ),
    );
  }
}

==> flutter_catalogue_widgets-0.0.14.tar.gz: lib/custom-circularprogressindicator.dart <==
/*
Description:
A loader or circular progress indicator that can be used to indicate the completeness of something or act as a splash/wait page or element.
There are two types of Circular Progress Indicators: Definite and Indefinite
- Indefinite progress indicators are indefinitely moving that can be used to showcase progress without any particular values.
- Defintie progress indicators intake a value and show the progress accordingly. For example, 0.6 will show an indicator that is 60% complete.

Imports:
import 'custom-circularprogressindicator.dart';
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';

Usage:
The user can pass in parameters to the widget like value color, background color, custom animator etc.

    Please Note:
    value = 0 or value = null will create an indefinte Progress indicator

    CustomCircularProgressIndicatorParameters Parameters = new CustomCircularProgressIndicatorParameters(value: 0, backgroundColor: Colors.red, valueColor: Colors.white);
    customisedCircularProgressIndicator(Parameters)

Author:
Soumyadeep Mitra
*/

import 'package:flutter/material.dart';
import 'theme.dart';
import 'widget-classesUsed.dart';
import 'consts.dart' as cons;

Widget customisedCircularProgressIndicator(CustomCircularProgressIndicatorParameters params) {
  // If no parameters are passed as a part of the widget call
  if(params == null){
    return Container(
      padding: cons.edgeInsetValues,
      child: CircularProgressIndicator(
        value: cons.intialValue,
        backgroundColor: mediumGreyThemeData().backgroundColor,
        valueColor: new AlwaysStoppedAnimation<Color>(
            mediumGreyThemeData().accentColor),
      ),
    );
  }
  else {
    // If all or limited parameters are passed as part of the parameters
    return Container(
      padding: cons.edgeInsetValues,
      child: CircularProgressIndicator(
        value: (params.value == 0 || params.value == null)
            ? null
            : params.value, // If value is null or 0, the bar is non-definite, else it will take the value
        backgroundColor: (params.backgroundColor!=null)?params.backgroundColor:mediumGreyThemeData().backgroundColor,
        valueColor: (params.valueColor!=null)?new AlwaysStoppedAnimation<Color>(params.valueColor):new AlwaysStoppedAnimation<Color>(
            mediumGreyThemeData().accentColor),
      ),
    );
  }
}
